HoverZoomState class

State class to manage hover zoom properties.

Constructors

HoverZoomState()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isHovering ↔ bool
getter/setter pair
mousePosition ↔ Offset
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited